@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2022 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -220,6 +220,8 @@ NotifyActor configuration, include NeverNotifyActor in the list of arguments.
 
 =cut
 
+our $ALWAYS_NOTIFY_ACTOR = 0;
+
 sub RemoveInappropriateRecipients {
     my $self = shift;
 
@@ -237,7 +239,7 @@ sub RemoveInappropriateRecipients {
         },
     ) if $args{NeverNotifyActor} ||
          (!RT->Config->Get('NotifyActor',$TransactionCurrentUser)
-         && !$args{AlwaysNotifyActor});
+         && !$args{AlwaysNotifyActor}) && !$ALWAYS_NOTIFY_ACTOR;
 
     $self->SUPER::RemoveInappropriateRecipients();
 }
