@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2022 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -266,6 +266,11 @@ sub LimitCustomField {
         EXPRESSION => 'main.id'
     );
 
+    $self->Limit(
+        LEFTJOIN => $ObjectValuesAlias,
+        FIELD    => 'ObjectType',
+        VALUE    => 'RT::Article',
+    );
     $self->Limit(
         LEFTJOIN => $ObjectValuesAlias,
         FIELD    => 'Disabled',
