@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -192,9 +192,8 @@ C<RealName> or building name).
 
 =item attr_map
 
-Mapping of RT attributes on to attributes in the external source.
-Valid keys are attributes of an L<RT::User>. The values are attributes from
-your authentication source. For example, an LDAP mapping might look like:
+Mapping of RT attributes on to attributes in the external source.  For
+example, an LDAP mapping might look like:
 
     'attr_map' => {
         'Name'         => 'sAMAccountName',
@@ -204,6 +203,83 @@ your authentication source. For example, an LDAP mapping might look like:
         ...
     },
 
+The values in the mapping (i.e. the fields in external source, the right hand
+side) can be one of the following:
+
+=over 4
+
+=item an attribute/field
+
+External field to use. Only first value is used if field is multivalue(could
+happen in LDAP). For example:
+
+    EmailAddress => 'mail',
+
+=item an array reference
+
+The LDAP attributes can also be an arrayref of external fields,
+for example:
+
+    WorkPhone => [qw/CompanyPhone Extension/]
+
+which will be concatenated together with a space. First values
+of each field are used in case they have multiple values.
+
+=item a subroutine reference
+
+The external field can also be a subroutine reference that does
+mapping. E.g.
+
+    YYY => sub {
+        my %args = @_;
+
+        return 'XXX' unless $args{external_entry};
+
+        my @values = grep defined && length, $args{external_entry}->get_value('XXX');
+        return @values;
+    },
+
+The following arguments are passed into the function in a hash:
+
+=over 4
+
+=item external_entry
+
+For type "ldap", it's an instance of L<Net::LDAP::Entry>.  For type "db", it's
+a hashref of the result row.
+
+=item mapping
+
+Hash reference of the attr_map value.
+
+=item rt_field and external_field
+
+The currently processed key and value from the mapping.
+
+=back
+
+The subroutine is called in 2 modes: when called with external_entry
+specified, it should return value or list of values, otherwise, it should
+return the external field list it depends on, so RT could retrieve them at the
+beginning.
+
+=back
+
+The keys in the mapping (i.e. the RT fields, the left hand side) may be a user
+custom field name prefixed with C<UserCF.>, for example C<< 'UserCF.Employee
+Number' => 'employeeId' >>.  Note that this only B<adds> values at the moment,
+which on single value CFs will remove any old value first.  Multiple value CFs
+may behave not quite how you expect.  If the attribute no longer exists on a
+user in external source, it will be cleared on the RT side as well.
+
+You may also prefix any RT custom field name with C<CF.> inside your mapping
+to add available values to a Select custom field.  This effectively takes user
+attributes in external source and adds the values as selectable options in a
+CF.  It does B<not> set a CF value on any RT object (User, Ticket, Queue,
+etc).  You might use this to populate a ticket Location CF with all the
+locations of your users so that tickets can be associated with the locations
+in use.
+
 =back
 
 =back
@@ -281,6 +357,7 @@ sub DoAuth {
     return (0, "User already logged in!") if ($session->{'CurrentUser'} && $session->{'CurrentUser'}->Id);
 
     # For each of those services..
+    my ( $matched_field, $matched_username );
     foreach my $service (@auth_services) {
 
         # Get the full configuration for that service as a hashref
@@ -305,6 +382,7 @@ sub DoAuth {
         # safely bypass the password checking later on; primarily because
         # it's VERY unlikely we even have a password to check if an SSO succeeded.
         my $pass_bypass = 0;
+        my $field;
         if(defined($username)) {
             $RT::Logger->debug("Pass not going to be checked, attempting SSO");
             $pass_bypass = 1;
@@ -327,7 +405,9 @@ sub DoAuth {
             # Don't continue unless the $username exists in the external service
 
             $RT::Logger->debug("Calling UserExists with \$username ($username) and \$service ($service)");
-            next unless RT::Authen::ExternalAuth::UserExists($username, $service);
+            $field = RT::Authen::ExternalAuth::UserExists( $username, $service ) or next;
+            # 1 means no field info, which will fall back to Name
+            undef $field if $field && $field eq '1';
         }
 
         ####################################################################
@@ -339,18 +419,16 @@ sub DoAuth {
 
         # Does user already exist internally to RT?
         $session->{'CurrentUser'} = RT::CurrentUser->new();
-        $session->{'CurrentUser'}->Load($username);
+        $session->{CurrentUser}->LoadByCols( $field || 'Name', $username );
 
         # Unless we have loaded a valid user with a UserID create one.
         unless ($session->{'CurrentUser'}->Id) {
             my $UserObj = RT::User->new($RT::SystemUser);
             my $create = RT->Config->Get('UserAutocreateDefaultsOnLogin')
                 || RT->Config->Get('AutoCreate');
-            my ($val, $msg) =
-                $UserObj->Create(%{ref($create) ? $create : {}},
-                                 Name   => $username,
-                                 Gecos  => $username,
-                             );
+
+            my ( $val, $msg ) = $UserObj->Create( %{ ref($create) ? $create : {} },
+                $field ? ( $field => $username ) : ( 'Name' => $username, Gecos => $username, ) );
             unless ($val) {
                 $RT::Logger->error( "Couldn't create user $username: $msg" );
                 next;
@@ -364,7 +442,7 @@ sub DoAuth {
             $RT::Logger->debug("Loading new user (",
                                                 $username,
                                                 ") into current session");
-            $session->{'CurrentUser'}->Load($username);
+            $session->{'CurrentUser'}->Load($UserObj->Id);
         }
 
         ####################################################################
@@ -386,7 +464,11 @@ sub DoAuth {
 
         # If the password check succeeded then this is our authoritative service
         # and we proceed to user information update and login.
-        last if $success;
+        if ( $success ) {
+            $matched_field = $field if $field;
+            $matched_username = $username;
+            last;
+        }
     }
 
     # If we got here and don't have a user loaded we must have failed to
@@ -426,7 +508,7 @@ sub DoAuth {
         if ( @{ RT->Config->Get('ExternalInfoPriority') } ) {
             # Note that UpdateUserInfo does not care how we authenticated the user
             # It will look up user info from whatever is specified in $RT::ExternalInfoPriority
-            ($info_updated,$info_updated_msg) = RT::Authen::ExternalAuth::UpdateUserInfo($session->{'CurrentUser'}->Name);
+            ($info_updated,$info_updated_msg) = RT::Authen::ExternalAuth::UpdateUserInfo($matched_username, $matched_field || 'Name');
         }
 
         # Now that we definitely have up-to-date user information,
@@ -464,7 +546,8 @@ sub DoAuth {
 }
 
 sub UpdateUserInfo {
-    my $username        = shift;
+    my $username = shift;
+    my $field    = shift || 'Name';
 
     # Prepare for the worst...
     my $found           = 0;
@@ -474,7 +557,7 @@ sub UpdateUserInfo {
     my $user_disabled   = RT::Authen::ExternalAuth::UserDisabled($username);
 
     my $UserObj = RT::User->new(RT->SystemUser);
-    $UserObj->Load($username);
+    $UserObj->LoadByCols($field => $username);
 
     # If user is disabled, set the RT::Principal to disabled and return out of the function.
     # I think it's a waste of time and energy to update a user's information if they are disabled
@@ -516,18 +599,21 @@ sub UpdateUserInfo {
     # Update their info from external service using the username as the lookup key
     # CanonicalizeUserInfo will work out for itself which service to use
     # Passing it a service instead could break other RT code
-    my %args = (Name => $username);
+    my %args = ($field => $username);
     $UserObj->CanonicalizeUserInfo(\%args);
 
     # For each piece of information returned by CanonicalizeUserInfo,
     # run the Set method for that piece of info to change it for the user
     my @results = $UserObj->Update(
         ARGSRef         => \%args,
-        AttributesRef   => [keys %args],
+        AttributesRef   => [ grep { !/^(?:User)?CF\./ } keys %args ],
     );
     $RT::Logger->debug("UPDATED user $username: $_")
         for @results;
 
+    AddCustomFieldValue( %args );
+    $UserObj->UpdateObjectCustomFieldValues( %args );
+
     # Confirm update success
     $updated = 1;
     $RT::Logger->debug( "UPDATED user (",
@@ -634,6 +720,44 @@ sub UserDisabled {
     return $user_disabled;
 }
 
+sub AddCustomFieldValue {
+    my %args = @_;
+
+    foreach my $rtfield ( keys %args ) {
+        next unless $rtfield =~ /^CF\.(.+)$/i;
+        my $cf_name = $1;
+
+        my $cfv_name = $args{$rtfield} or next;
+
+        my $cf = RT::CustomField->new($RT::SystemUser);
+        my ( $status, $msg ) = $cf->Load($cf_name);
+        unless ($status) {
+            $RT::Logger->error("Couldn't load CF [$cf_name]: $msg");
+            next;
+        }
+
+        my $cfv = RT::CustomFieldValue->new($RT::SystemUser);
+        $cfv->LoadByCols(
+            CustomField => $cf->id,
+            Name        => $cfv_name
+        );
+        if ( $cfv->id ) {
+            $RT::Logger->debug("Custom Field '$cf_name' already has '$cfv_name' for a value");
+            next;
+        }
+
+        ( $status, $msg ) = $cf->AddValue( Name => $cfv_name );
+        if ($status) {
+            $RT::Logger->debug("Added '$cfv_name' to Custom Field '$cf_name' [$msg]");
+        }
+        else {
+            $RT::Logger->error("Couldn't add '$cfv_name' to '$cf_name' [$msg]");
+        }
+    }
+
+    return;
+}
+
 RT::Base->_ImportOverlays();
 
 1;
