@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -471,28 +471,6 @@ sub _Set {
     return ($txn_id, scalar $txn->BriefDescription);
 }
 
-=head2 Lifecycle [CONTEXT_OBJ]
-
-Returns the current value of Lifecycle.
-
-Provide an optional asset object as context to check role-level rights
-in addition to catalog-level rights for ShowCatalog and AdminCatalog.
-
-(In the database, Lifecycle is stored as varchar(32).)
-=cut
-
-sub Lifecycle {
-    my $self    = shift;
-    my $context_obj = shift;
-
-    if ( $context_obj && $context_obj->CatalogObj->Id eq $self->Id &&
-        ( $context_obj->CurrentUserHasRight('ShowCatalog') or $context_obj->CurrentUserHasRight('AdminCatalog') ) ) {
-        return ( $self->__Value('Lifecycle') );
-    }
-
-    return ( $self->_Value('Lifecycle') );
-}
-
 =head2 _Value
 
 Checks L</CurrentUserCanSee> before calling C<SUPER::_Value>.
