@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -65,10 +65,14 @@ Applies if Starts date is not set for the ticket.
 
 sub IsApplicable {
     my $self = shift;
-    return 0 if $self->TicketObj->StartsObj->Unix > 0;
     return 0 if $self->TicketObj->QueueObj->SLADisabled;
     return 0 unless $self->TicketObj->SLA;
-    return 1;
+
+    my $type = $self->TransactionObj->Type;
+    return 1 if $type eq 'Create';
+    return 1 if $type eq 'Set' && $self->TransactionObj->Field eq 'SLA';
+
+    return 0;
 }
 
 1;
