@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -123,6 +123,11 @@ sub _Set {
         return (0, $self->loc('Permission Denied')); 
     } 
 
+    # disallow non-integer sort order
+    if ( $args{Field} eq 'SortOrder' and ( $args{Value} // '' ) !~ /^(?:-?\d+)?$/ ) {
+        return (0, $self->loc("SortOrder must be an integer value."));
+    }
+
     my ($ret, $msg) = $self->SUPER::_Set( @_ ); 
     if ( $args{Field} eq 'Name' ) {
         $cf->CleanupDefaultValues;
