@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,13 +51,9 @@ use strict;
 use warnings;
 
 my %MODULES = (
-    '2.2' => {
-        "mod_perl" => [qw(authz_host env alias perl)],
-        "fastcgi"  => [qw(authz_host env alias mime fastcgi)],
-    },
     '2.4' => {
         "mod_perl" => [qw(mpm_worker authz_core authn_core authz_host env alias perl)],
-        "fastcgi"  => [qw(mpm_worker authz_core authn_core authz_host env alias mime fastcgi)],
+        "fcgid"  => [qw(mpm_prefork authz_core authn_core authz_host env alias mime fcgid)],
     },
 );
 
@@ -242,6 +238,7 @@ sub apache_server_info {
         if $mpm;
     print $tmp "ErrorLog /dev/null\n";
     print $tmp "TransferLog /dev/null\n";
+    print $tmp "ServerName localhost\n";
     close $tmp;
     $info = `$res{executable} -V -f $tmp`;
     my %opts = ($info =~ m/^\s*-D\s+([A-Z_]+?)(?:="(.*)")$/mg);
