@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2019 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -242,6 +242,18 @@ sub LimitToUnprivileged {
     $self->MemberOfGroup( RT->UnprivilegedUsers->id);
 }
 
+=head2 LimitToEndUsers
+
+Limits to end users only, i.e. no internal users "RT_System" and "Nobody".
+
+=cut
+
+sub LimitToEndUsers {
+    my $self = shift;
+    for my $user ( RT->SystemUser, RT->Nobody ) {
+        $self->Limit( FIELD => 'id', VALUE => $user->Id, OPERATOR => '!=', ENTRYAGGREGATOR => 'AND' );
+    }
+}
 
 sub Limit {
     my $self = shift;
@@ -337,20 +349,30 @@ sub _JoinACL
     }
 
     my $acl = $self->NewAlias('ACL');
-    $self->Limit(
-        ALIAS    => $acl,
-        FIELD    => 'RightName',
-        OPERATOR => ( $args{Right} ? '=' : 'IS NOT' ),
-        VALUE => $args{Right} || 'NULL',
-        ENTRYAGGREGATOR => 'OR'
-    );
-    if ( $args{'IncludeSuperusers'} and $args{'Right'} ) {
+    if ( $args{Right} ) {
+        if ( $args{'IncludeSuperusers'} && $args{Right} ne 'SuperUser' ) {
+            $self->Limit(
+                ALIAS    => $acl,
+                FIELD    => 'RightName',
+                OPERATOR => 'IN',
+                VALUE    => [ 'SuperUser', $args{Right} ],
+            );
+        }
+        else {
+            $self->Limit(
+                ALIAS    => $acl,
+                FIELD    => 'RightName',
+                OPERATOR => '=',
+                VALUE    => $args{Right},
+            );
+        }
+    }
+    else {
         $self->Limit(
-            ALIAS           => $acl,
-            FIELD           => 'RightName',
-            OPERATOR        => '=',
-            VALUE           => 'SuperUser',
-            ENTRYAGGREGATOR => 'OR'
+            ALIAS    => $acl,
+            FIELD    => 'RightName',
+            OPERATOR => 'IS NOT',
+            VALUE    => 'NULL',
         );
     }
     return $acl;
